@@ -68,19 +68,44 @@ TMP_DIR = RUNTIME_ROOT / "tmp"
 GRAPHCMD_FILE = TMP_DIR / "graphcmd.png"
 LASTWEEKCMD_FILE = TMP_DIR / "lastweek.png"
 
-with open(STRINGS_DATA_FILE) as f:
-    STRINGS = load(f, Loader=Loader)
+# loaded application data
+STRINGS = None
+FISH = None
+BUGS = None
+ART = None
+FOSSILS_SET = None
+FISH_SET = None
+BUGS_SET = None
+ART_SET = None
+COLLECTABLE_SET = None
 
-FISH = pd.read_csv(FISH_DATA_FILE)
-BUGS = pd.read_csv(BUGS_DATA_FILE)
-ART = pd.read_csv(ART_DATA_FILE)
 
-with open(FOSSILS_DATA_FILE) as f:
-    FOSSILS_SET = frozenset([line.strip().lower() for line in f.readlines()])
-FISH_SET = frozenset(FISH.drop_duplicates(subset="name").name.tolist())
-BUGS_SET = frozenset(BUGS.drop_duplicates(subset="name").name.tolist())
-ART_SET = frozenset(ART.drop_duplicates(subset="name").name.tolist())
-COLLECTABLE_SET = FOSSILS_SET | FISH_SET | BUGS_SET | ART_SET
+def load_application_data():
+    """Defer loading these assests until we actually need them."""
+    global STRINGS
+    global FISH
+    global BUGS
+    global ART
+    global FOSSILS_SET
+    global FISH_SET
+    global BUGS_SET
+    global ART_SET
+    global COLLECTABLE_SET
+
+    with open(STRINGS_DATA_FILE) as f:
+        STRINGS = load(f, Loader=Loader)
+
+    FISH = pd.read_csv(FISH_DATA_FILE)
+    BUGS = pd.read_csv(BUGS_DATA_FILE)
+    ART = pd.read_csv(ART_DATA_FILE)
+
+    with open(FOSSILS_DATA_FILE) as f:
+        FOSSILS_SET = frozenset([line.strip().lower() for line in f.readlines()])
+    FISH_SET = frozenset(FISH.drop_duplicates(subset="name").name.tolist())
+    BUGS_SET = frozenset(BUGS.drop_duplicates(subset="name").name.tolist())
+    ART_SET = frozenset(ART.drop_duplicates(subset="name").name.tolist())
+    COLLECTABLE_SET = FOSSILS_SET | FISH_SET | BUGS_SET | ART_SET
+
 
 EMBED_LIMIT = 5  # more embeds in a row than this causes issues
 
@@ -318,6 +343,8 @@ class Turbot(discord.Client):
             if hasattr(member[1], "is_command") and member[1].is_command
         ]
 
+        load_application_data()
+
     def run(self):  # pragma: no cover
         super().run(self.token)
 
@@ -475,9 +502,12 @@ class Turbot(discord.Client):
             island.name, list(island.model_group.models), island.previous_week, True
         )
 
+        ax = plt.gca()
+        if "!!ERROR!!" in ax.get_title():
+            return None
+
         # fit the y-axis to the plotted data
         maximum = 0
-        ax = plt.gca()
         for line in ax.lines:
             for price in line.get_ydata():
                 if price > maximum:
@@ -553,9 +583,10 @@ class Turbot(discord.Client):
 
     def generate_graph(self, channel, target_user, graphname):  # pragma: no cover
         """Generates a nice looking graph of user data."""
-        fig = self.get_graph(channel, target_user, graphname)
-        if fig:
-            plt.close("all")
+        plot = self.get_graph(channel, target_user, graphname)
+        success = plot is not None
+        plt.close("all")
+        return success
 
     def append_price(self, author, kind, price, at):
         """Adds a price to the prices data file for the given author and kind."""
@@ -945,8 +976,9 @@ class Turbot(discord.Client):
         """
         Generates a historical graph of turnip prices for all users.
         """
-        self.generate_graph(channel, None, GRAPHCMD_FILE)
-        return s("graph_all_users"), discord.File(GRAPHCMD_FILE)
+        success = self.generate_graph(channel, None, GRAPHCMD_FILE)
+        attach = discord.File(GRAPHCMD_FILE) if success else None
+        return s("graph_all_users"), attach
 
     @command
     def history(self, channel, author, params):
@@ -1526,10 +1558,11 @@ class Turbot(discord.Client):
         if not timeline[0]:
             return s("cant_find_buy", name=target_name), None
 
-        self.generate_graph(channel, target_user, GRAPHCMD_FILE)
+        success = self.generate_graph(channel, target_user, GRAPHCMD_FILE)
         query = ".".join((str(price) if price else "") for price in timeline).rstrip(".")
         url = f"{self.base_prophet_url}{query}"
-        return s("predict", name=target_name, url=url), discord.File(GRAPHCMD_FILE)
+        attach = discord.File(GRAPHCMD_FILE) if success else None
+        return s("predict", name=target_name, url=url), attach
 
     @command
     def pref(self, channel, author, params):
